@@ -16,17 +16,13 @@
  */
 package org.apache.qpid.jms;
 
-import static org.junit.jupiter.api.Assertions.assertThrows;
+import jakarta.jms.IllegalStateException;
+import jakarta.jms.JMSException;
+import jakarta.jms.ServerSessionPool;
+import jakarta.jms.Session;
 
-import javax.jms.IllegalStateException;
-import javax.jms.JMSException;
-import javax.jms.ServerSessionPool;
-import javax.jms.Session;
-
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInfo;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Test various contract aspects of the TopicConnection implementation
@@ -34,27 +30,21 @@ import org.junit.jupiter.api.Timeout;
 public class JmsTopicConnectionTest extends JmsConnectionTestSupport {
 
     @Override
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        super.setUp(testInfo);
+    @Before
+    public void setUp() throws Exception {
+        super.setUp();
 
         topicConnection = createTopicConnectionToMockProvider();
         topicConnection.start();
     }
 
-    @Test
-    @Timeout(30)
-    public void testCreateConnectionConsumerOnTopicConnection() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            topicConnection.createConnectionConsumer(new JmsQueue(), "subscriptionName", (ServerSessionPool) null, 1);
-        });
+    @Test(timeout = 30000, expected=IllegalStateException.class)
+    public void testCreateConnectionConsumerOnTopicConnection() throws JMSException{
+        topicConnection.createConnectionConsumer(new JmsQueue(), "subscriptionName", (ServerSessionPool)null, 1);
     }
 
-    @Test
-    @Timeout(30)
-    public void testCreateQueueSessionOnTopicConnection() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            topicConnection.createQueueSession(false, Session.AUTO_ACKNOWLEDGE);
-        });
+    @Test(timeout = 30000, expected=IllegalStateException.class)
+    public void testCreateQueueSessionOnTopicConnection() throws JMSException{
+        topicConnection.createQueueSession(false, Session.AUTO_ACKNOWLEDGE);
     }
 }
\ No newline at end of file
