@@ -20,20 +20,19 @@
  */
 package org.apache.qpid.jms.integration;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNotSame;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNotSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.net.URI;
 import java.util.UUID;
 
-import javax.jms.Connection;
-import javax.jms.JMSException;
-import javax.jms.QueueConnection;
-import javax.jms.TopicConnection;
+import jakarta.jms.Connection;
+import jakarta.jms.JMSException;
+import jakarta.jms.QueueConnection;
+import jakarta.jms.TopicConnection;
 
 import org.apache.qpid.jms.JmsConnection;
 import org.apache.qpid.jms.JmsConnectionFactory;
@@ -51,8 +50,7 @@ import org.apache.qpid.jms.policy.JmsPresettlePolicy;
 import org.apache.qpid.jms.policy.JmsRedeliveryPolicy;
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.apache.qpid.jms.test.testpeer.TestAmqpPeer;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -60,8 +58,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
 
     private static final Logger LOG = LoggerFactory.getLogger(ConnectionFactoryIntegrationTest.class);
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testCreateConnectionGoodProviderURI() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Ignore errors from peer close due to not sending any Open / Close frames
@@ -85,8 +82,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testCreateConnectionGoodProviderString() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Ignore errors from peer close due to not sending any Open / Close frames
@@ -110,8 +106,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testTopicCreateConnectionGoodProviderString() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Ignore errors from peer close due to not sending any Open / Close frames
@@ -135,8 +130,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testCreateQueueConnectionGoodProviderString() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Ignore errors from peer close due to not sending any Open / Close frames
@@ -160,8 +154,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testUriOptionsAppliedToConnection() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Ignore errors from peer close due to not sending any Open / Close frames
@@ -191,71 +184,21 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
-    public void testCreateAmqpConnectionFactoryWithUserInfoThrowsIAE() throws Exception {
+    @Test(timeout=20000)
+    public void testCreateAmqpConnectionWithUserInfoThrowsJMSEx() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // DONT create a test fixture, we will drive everything directly.
             String uri = "amqp://user:pass@127.0.0.1:" + testPeer.getServerPort();
             try {
                 new JmsConnectionFactory(uri);
                 fail("Should not be able to create a factory with user info value set.");
-            } catch (IllegalArgumentException iae) {
-                LOG.debug("Caught expected exception on invalid URI: {}", iae);
-                assertNotNull(iae.getMessage());
-                assertEquals("The supplied URI cannot contain a User-Info section", iae.getMessage());
+            } catch (Exception ex) {
+                LOG.debug("Caught expected exception on invalid message ID format: {}", ex);
             }
-
-            testPeer.close();
-            assertNull(testPeer.getClientSocket(), "Peer should not have accepted any connection");
         }
     }
 
-    @Test
-    @Timeout(20)
-    public void testCreateFailoverConnectionFactoryWithComponentUriHavingUserInfoThrowsIAE() throws Exception {
-        try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
-            // DONT create a test fixture, we will drive everything directly.
-            int peerPort = testPeer.getServerPort();
-
-            // Have sole server component URI be invalid
-            final String failoverURIsingle = "failover:(amqp://user:pass@localhost:" + peerPort + ")?failover.maxReconnectAttempts=1";
-            doCreateFailoverConnectionFactoryWithComponentUriHavingUserInfoThrowsIAETestImpl(failoverURIsingle);
-
-            // Have first server component URI be invalid
-            final String failoverURIfirst = "failover:(amqp://user:pass@localhost:" + peerPort + ",amqp://127.0.0.1:" + peerPort + ")?failover.maxReconnectAttempts=1";
-            doCreateFailoverConnectionFactoryWithComponentUriHavingUserInfoThrowsIAETestImpl(failoverURIfirst);
-
-            // Have last server component URI be invalid
-            final String failoverURIlast = "failover:(amqp://127.0.0.1:" + peerPort + ",amqp://user:pass@localhost:" + peerPort + ")?failover.maxReconnectAttempts=1";
-            doCreateFailoverConnectionFactoryWithComponentUriHavingUserInfoThrowsIAETestImpl(failoverURIlast);
-
-            // Have a middle server component URI be invalid
-            final String failoverURImiddle = "failover:(amqp://127.0.0.1:" + peerPort + ",amqp://user:pass@localhost:" + peerPort + ",amqp://127.0.0.1:" + peerPort + ")?failover.maxReconnectAttempts=1";
-            doCreateFailoverConnectionFactoryWithComponentUriHavingUserInfoThrowsIAETestImpl(failoverURImiddle);
-
-            // Have multiple server component URIs be invalid
-            final String failoverURImultiple = "failover:(amqp://user:pass@127.0.0.1:" + peerPort + ",amqp://user:pass@localhost:" + peerPort + ",amqp://user:pass@127.0.0.1:" + peerPort + ")?failover.maxReconnectAttempts=1";
-            doCreateFailoverConnectionFactoryWithComponentUriHavingUserInfoThrowsIAETestImpl(failoverURImultiple);
-
-            testPeer.close();
-            assertNull(testPeer.getClientSocket(), "Peer should not have accepted any connection");
-        }
-    }
-
-    private void doCreateFailoverConnectionFactoryWithComponentUriHavingUserInfoThrowsIAETestImpl(String failoverURI) {
-        try {
-            new JmsConnectionFactory(failoverURI);
-            fail("Should not be able to create a factory when failover URI contains component entry with user info value set.");
-        } catch (IllegalArgumentException iae) {
-            LOG.debug("Caught expected exception on invalid URI: {}", iae);
-            assertNotNull(iae.getMessage());
-            assertEquals("The component server URIs cannot contain a User-Info section", iae.getMessage());
-        }
-    }
-
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testSetInvalidMessageIDFormatOption() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // DONT create a test fixture, we will drive everything directly.
@@ -269,8 +212,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testSetMessageIDFormatOptionAlteredCase() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // DONT create a test fixture, we will drive everything directly.
@@ -294,8 +236,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testMessageIDFormatOptionApplied() throws Exception {
         BUILTIN[] formatters = JmsMessageIDBuilder.BUILTIN.values();
 
@@ -327,8 +268,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testSetCustomMessageIDBuilder() throws Exception {
         CustomJmsMessageIdBuilder custom = new CustomJmsMessageIdBuilder();
 
@@ -359,8 +299,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testSetCustomMessageIDPolicy() throws Exception {
         CustomJmsMessageIDPolicy custom = new CustomJmsMessageIDPolicy();
 
@@ -391,8 +330,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testSetCustomPrefetchPolicy() throws Exception {
         CustomJmsPrefetchPolicy custom = new CustomJmsPrefetchPolicy();
 
@@ -423,8 +361,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testSetCustomPresettlePolicy() throws Exception {
         CustomJmsPresettlePolicy custom = new CustomJmsPresettlePolicy();
 
@@ -455,8 +392,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testSetCustomRedeliveryPolicy() throws Exception {
         CustomJmsRedeliveryPolicy custom = new CustomJmsRedeliveryPolicy();
 
@@ -487,8 +423,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout=10000)
     public void testMessageIDPolicyCannotBeNulled() throws Exception {
         CustomJmsMessageIDPolicy custom = new CustomJmsMessageIDPolicy();
 
@@ -502,8 +437,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         assertTrue(factory.getMessageIDPolicy() instanceof JmsDefaultMessageIDPolicy);
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout=10000)
     public void testPrefetchPolicyCannotBeNulled() throws Exception {
         CustomJmsPrefetchPolicy custom = new CustomJmsPrefetchPolicy();
 
@@ -517,8 +451,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         assertTrue(factory.getPrefetchPolicy() instanceof JmsDefaultPrefetchPolicy);
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout=10000)
     public void testPresettlePolicyCannotBeNulled() throws Exception {
         CustomJmsPresettlePolicy custom = new CustomJmsPresettlePolicy();
 
@@ -532,8 +465,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         assertTrue(factory.getPresettlePolicy() instanceof JmsDefaultPresettlePolicy);
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout=10000)
     public void testRedeliveryPolicyCannotBeNulled() throws Exception {
         CustomJmsRedeliveryPolicy custom = new CustomJmsRedeliveryPolicy();
 
@@ -547,20 +479,17 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         assertTrue(factory.getRedeliveryPolicy() instanceof JmsDefaultRedeliveryPolicy);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20_000)
     public void testConfigureFutureFactoryFromURITypeOfProgressive() throws Exception {
         doTestCreateConnectionWithConfiguredFutureFactory("progressive");
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20_000)
     public void testConfigureFutureFactoryFromURITypeOfBalanced() throws Exception {
         doTestCreateConnectionWithConfiguredFutureFactory("balanced");
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20_000)
     public void testConfigureFutureFactoryFromURITypeOfConservative() throws Exception {
         doTestCreateConnectionWithConfiguredFutureFactory("conservative");
     }
@@ -591,8 +520,7 @@ public class ConnectionFactoryIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20_000)
     public void testConfigureFutureFactoryFromURITypeUnknown() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Ignore errors from peer close due to not sending any Open / Close frames
