@@ -19,28 +19,28 @@ package org.apache.qpid.jms.message;
 import static org.apache.qpid.jms.message.JmsMessageSupport.ACCEPTED;
 import static org.apache.qpid.jms.message.JmsMessageSupport.JMS_AMQP_ACK_TYPE;
 import static org.apache.qpid.jms.message.JmsMessageSupport.RELEASED;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.Serializable;
 import java.util.Enumeration;
 import java.util.Map;
 import java.util.UUID;
 
-import javax.jms.BytesMessage;
-import javax.jms.DeliveryMode;
-import javax.jms.JMSException;
-import javax.jms.MapMessage;
-import javax.jms.Message;
-import javax.jms.MessageFormatException;
-import javax.jms.MessageNotWriteableException;
-import javax.jms.ObjectMessage;
-import javax.jms.StreamMessage;
-import javax.jms.TextMessage;
+import jakarta.jms.BytesMessage;
+import jakarta.jms.DeliveryMode;
+import jakarta.jms.JMSException;
+import jakarta.jms.MapMessage;
+import jakarta.jms.Message;
+import jakarta.jms.MessageFormatException;
+import jakarta.jms.MessageNotWriteableException;
+import jakarta.jms.ObjectMessage;
+import jakarta.jms.StreamMessage;
+import jakarta.jms.TextMessage;
 
 import org.apache.qpid.jms.JmsAcknowledgeCallback;
 import org.apache.qpid.jms.JmsConnection;
@@ -50,8 +50,8 @@ import org.apache.qpid.jms.JmsTopic;
 import org.apache.qpid.jms.message.facade.JmsMessageFacade;
 import org.apache.qpid.jms.message.facade.test.JmsTestMessageFacade;
 import org.apache.qpid.jms.message.facade.test.JmsTestMessageFactory;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
+import org.junit.Before;
+import org.junit.Test;
 import org.mockito.Mockito;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -74,7 +74,7 @@ public class JmsMessageTest {
     private long jmsTimestamp;
     private long[] consumerIDs;
 
-    @BeforeEach
+    @Before
     public void setUp() throws Exception {
         this.jmsMessageID = "ID:TEST-ID:0:0:0:1";
         this.jmsCorrelationID = "testcorrelationid";
@@ -445,9 +445,9 @@ public class JmsMessageTest {
         assertTrue(testFacade.propertyExists(invalidPropName));
 
         if(!disableValidation) {
-            assertFalse(msg.propertyExists(invalidPropName), "Property should be indicated to not exist");
+            assertFalse("Property should be indicated to not exist", msg.propertyExists(invalidPropName));
         } else {
-            assertTrue(msg.propertyExists(invalidPropName), "Property should be indicated to exist");
+            assertTrue("Property should be indicated to exist", msg.propertyExists(invalidPropName));
         }
     }
 
@@ -575,10 +575,10 @@ public class JmsMessageTest {
             jmsxNameFound |= element.equals(jmsxName);
             headerNameFound1 |= element.equals(headerName);
         }
-        assertTrue(propNameFound, "prop name not found");
-        assertTrue(jmsxNameFound, "jmsx prop name not found");
+        assertTrue("prop name not found", propNameFound);
+        assertTrue("jmsx prop name not found", jmsxNameFound);
         // spec compliance, only non-'JMS header' props returned
-        assertFalse(headerNameFound1, "header name should not have been found");
+        assertFalse("header name should not have been found", headerNameFound1);
     }
 
     @Test
@@ -626,18 +626,18 @@ public class JmsMessageTest {
         }
 
         if (!disableValidation) {
-            assertFalse(invalidPropName1Found, "Invalid prop name 1 was found");
-            assertFalse(invalidPropName2Found, "Invalid prop name 2 was found");
+            assertFalse("Invalid prop name 1 was found", invalidPropName1Found);
+            assertFalse("Invalid prop name 2 was found", invalidPropName2Found);
         } else {
-            assertTrue(invalidPropName1Found, "Invalid prop name 1 was not found");
-            assertTrue(invalidPropName2Found, "Invalid prop name 2 was not found");
+            assertTrue("Invalid prop name 1 was not found", invalidPropName1Found);
+            assertTrue("Invalid prop name 2 was not found", invalidPropName2Found);
         }
-        assertTrue(validPropNameFound, "valid prop name was not found");
+        assertTrue("valid prop name was not found", validPropNameFound);
     }
 
     @Test
     @SuppressWarnings("rawtypes")
-    void testGetAllPropertyNames() throws JMSException {
+    public void testGetAllPropertyNames() throws JMSException {
         JmsMessage msg = factory.createMessage();
         String name1 = "floatProperty";
         msg.setFloatProperty(name1, 1.3f);
@@ -654,9 +654,9 @@ public class JmsMessageTest {
             found2 |= element.equals(name2);
             found3 |= element.equals(name3);
         }
-        assertTrue(found1, "prop name1 found");
-        assertTrue(found2, "prop name2 found");
-        assertTrue(found3, "prop name4 found");
+        assertTrue("prop name1 found", found1);
+        assertTrue("prop name2 found", found2);
+        assertTrue("prop name4 found", found3);
     }
 
     @Test
@@ -755,7 +755,7 @@ public class JmsMessageTest {
         JmsMessage msg = factory.createMessage();
         msg.setIntProperty("JMSXDeliveryCount", 1);
         int count = msg.getIntProperty("JMSXDeliveryCount");
-        assertTrue(count == 1, "expected delivery count = 1 - got: " + count);
+        assertTrue("expected delivery count = 1 - got: " + count, count == 1);
     }
 
     @Test
@@ -1237,7 +1237,7 @@ public class JmsMessageTest {
     /**
      * Property 'identifiers' (i.e. names) must begin with a letter for which
      * {@link Character#isJavaLetter(char)} is true, as described in
-     * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
+     * {@link jakarta.jms.Message}. Verify an IAE is thrown if setting a property
      * beginning with a non-letter character.
      *
      * @throws Exception if an error occurs during the test.
@@ -1256,7 +1256,7 @@ public class JmsMessageTest {
     /**
      * Property 'identifiers' (i.e. names) must continue with a letter or digit
      * for which {@link Character#isJavaLetterOrDigit(char)} is true, as
-     * described in {@link javax.jms.Message}. Verify an IAE is thrown if
+     * described in {@link jakarta.jms.Message}. Verify an IAE is thrown if
      * setting a property continuing with a non-letter-or-digit character.
      *
      * @throws Exception if an error occurs during the test.
@@ -1294,7 +1294,7 @@ public class JmsMessageTest {
 
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NULL, TRUE, or
-     * FALSE, as described in {@link javax.jms.Message}. Verify an IAE is thrown
+     * FALSE, as described in {@link jakarta.jms.Message}. Verify an IAE is thrown
      * if setting a property with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1311,7 +1311,7 @@ public class JmsMessageTest {
 
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NULL, TRUE, or
-     * FALSE, as described in {@link javax.jms.Message}. Verify an IAE is thrown
+     * FALSE, as described in {@link jakarta.jms.Message}. Verify an IAE is thrown
      * if setting a property with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1328,7 +1328,7 @@ public class JmsMessageTest {
 
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NULL, TRUE, or
-     * FALSE, as described in {@link javax.jms.Message}. Verify an IAE is thrown
+     * FALSE, as described in {@link jakarta.jms.Message}. Verify an IAE is thrown
      * if setting a property with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1346,7 +1346,7 @@ public class JmsMessageTest {
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NOT, AND, OR,
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
-     * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
+     * {@link jakarta.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1364,7 +1364,7 @@ public class JmsMessageTest {
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NOT, AND, OR,
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
-     * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
+     * {@link jakarta.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1382,7 +1382,7 @@ public class JmsMessageTest {
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NOT, AND, OR,
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
-     * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
+     * {@link jakarta.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1400,7 +1400,7 @@ public class JmsMessageTest {
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NOT, AND, OR,
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
-     * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
+     * {@link jakarta.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1418,7 +1418,7 @@ public class JmsMessageTest {
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NOT, AND, OR,
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
-     * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
+     * {@link jakarta.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1436,7 +1436,7 @@ public class JmsMessageTest {
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NOT, AND, OR,
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
-     * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
+     * {@link jakarta.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1454,7 +1454,7 @@ public class JmsMessageTest {
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NOT, AND, OR,
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
-     * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
+     * {@link jakarta.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1472,7 +1472,7 @@ public class JmsMessageTest {
     /**
      * Property 'identifiers' (i.e. names) are not allowed to be NOT, AND, OR,
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
-     * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
+     * {@link jakarta.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
      *
      * @throws Exception if an error occurs during the test.
@@ -1525,11 +1525,11 @@ public class JmsMessageTest {
         JmsAcknowledgeCallback callback = new JmsAcknowledgeCallback(session);
         message.setAcknowledgeCallback(callback);
 
-        assertEquals(ACCEPTED, callback.getAckType(), "Unexpected ack type value");
+        assertEquals("Unexpected ack type value", ACCEPTED, callback.getAckType());
 
         message.setIntProperty(JMS_AMQP_ACK_TYPE, RELEASED);
 
-        assertEquals(RELEASED, callback.getAckType(), "Unexpected ack type value after setting prop");
+        assertEquals("Unexpected ack type value after setting prop", RELEASED, callback.getAckType());
     }
 
     //--------- Test isBodyAssignableTo method -------------------------------//
