@@ -16,12 +16,12 @@
  */
 package org.apache.qpid.jms.util;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertSame;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
 
 import java.lang.reflect.Field;
 import java.util.ArrayList;
@@ -31,14 +31,13 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.Condition;
 import java.util.concurrent.locks.ReentrantLock;
 
-import javax.jms.JMSException;
+import jakarta.jms.JMSException;
 
 import org.apache.qpid.jms.message.JmsInboundMessageDispatch;
 import org.apache.qpid.jms.message.JmsMessage;
 import org.apache.qpid.jms.message.facade.test.JmsTestMessageFacade;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Test the FIFO based message queue.
@@ -49,7 +48,7 @@ public class FifoMessageQueueTest {
     private final IdGenerator messageId = new IdGenerator();
     private long sequence;
 
-    @BeforeEach
+    @Before
     public void setUp() {
         queue = new FifoMessageQueue(1000);
         queue.start();
@@ -195,8 +194,7 @@ public class FifoMessageQueueTest {
         assertTrue(queue.isEmpty());
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout = 10000)
     public void testDequeueWaitsUntilMessageArrives() throws InterruptedException {
         final JmsInboundMessageDispatch message = createEnvelope();
         Thread runner = new Thread(new Runnable() {
@@ -215,14 +213,12 @@ public class FifoMessageQueueTest {
         assertSame(message, queue.dequeue(-1));
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout = 10000)
     public void testDequeueWaitsUntilMessageArrivesWhenLockNotified() throws Exception {
         doDequeueWaitsUntilMessageArrivesWhenLockNotifiedTestImpl(-1);
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout = 10000)
     public void testTimedDequeueWaitsUntilMessageArrivesWhenLockNotified() throws Exception {
         doDequeueWaitsUntilMessageArrivesWhenLockNotifiedTestImpl(100000);
     }
@@ -256,8 +252,7 @@ public class FifoMessageQueueTest {
         assertSame(message, queue.dequeue(timeout));
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout = 10000)
     public void testDequeueReturnsWhenQueueIsStopped() throws InterruptedException {
         Thread runner = new Thread(new Runnable() {
 
@@ -351,7 +346,7 @@ public class FifoMessageQueueTest {
             }
         }
 
-        assertNotNull(lock, "MessageQueue implementation unknown");
+        assertNotNull("MessageQueue implementation unknown", lock);
         lock.setAccessible(true);
         condition.setAccessible(true);
 
