@@ -16,24 +16,24 @@
  */
 package org.apache.qpid.jms.bench;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 
 import java.util.ArrayList;
 import java.util.List;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.DeliveryMode;
-import javax.jms.Destination;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageListener;
-import javax.jms.MessageProducer;
-import javax.jms.Queue;
-import javax.jms.Session;
-import javax.jms.TextMessage;
+import jakarta.jms.DeliveryMode;
+import jakarta.jms.Destination;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageListener;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
+import jakarta.jms.TextMessage;
 
 import org.apache.activemq.broker.BrokerService;
 import org.apache.activemq.broker.jmx.QueueViewMBean;
@@ -41,13 +41,13 @@ import org.apache.activemq.broker.region.policy.PolicyEntry;
 import org.apache.activemq.broker.region.policy.PolicyMap;
 import org.apache.activemq.broker.region.policy.VMPendingQueueMessageStoragePolicy;
 import org.apache.qpid.jms.support.AmqpTestSupport;
-import org.junit.jupiter.api.Disabled;
-import org.junit.jupiter.api.Test;
+import org.junit.Ignore;
+import org.junit.Test;
 
 /**
  *
  */
-@Disabled
+@Ignore
 public class ConsumeFromAMQPTest extends AmqpTestSupport {
 
     private final int MSG_COUNT = 50 * 1000;
@@ -94,14 +94,14 @@ public class ConsumeFromAMQPTest extends AmqpTestSupport {
         producer.close();
 
         QueueViewMBean queueView = getProxyToQueue(getDestinationName());
-        assertEquals(1, queueView.getQueueSize(), "Queue should have a message");
+        assertEquals("Queue should have a message", 1, queueView.getQueueSize());
 
         MessageConsumer consumer = session.createConsumer(queue);
         Message received = consumer.receive(7000);
         assertNotNull(received);
         consumer.close();
 
-        assertEquals(0, queueView.getQueueSize(), "Queue should have ano messages");
+        assertEquals("Queue should have ano messages", 0, queueView.getQueueSize());
     }
 
     @Test
@@ -171,7 +171,7 @@ public class ConsumeFromAMQPTest extends AmqpTestSupport {
         long startTime = System.currentTimeMillis();
         for (int i = 0; i < msgCount; ++i) {
             Message message = consumer.receive(7000);
-            assertNotNull(message, "Failed to receive message " + i);
+            assertNotNull("Failed to receive message " + i, message);
         }
         long result = (System.currentTimeMillis() - startTime);
 
