@@ -16,27 +16,26 @@
  */
 package org.apache.qpid.jms.consumer;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 
 import java.net.URI;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageProducer;
-import javax.jms.Queue;
-import javax.jms.Session;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
 
 import org.apache.qpid.jms.JmsConnection;
 import org.apache.qpid.jms.JmsConnectionListener;
 import org.apache.qpid.jms.message.JmsInboundMessageDispatch;
 import org.apache.qpid.jms.support.AmqpTestSupport;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 
 /**
  * Test for Message priority ordering.
@@ -45,8 +44,7 @@ public class JmsConsumerPriorityDispatchTest extends AmqpTestSupport {
 
     private final int MSG_COUNT = 10;
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testPrefetchedMessageArePriorityOrdered() throws Exception {
 
         final CountDownLatch received = new CountDownLatch(MSG_COUNT);
@@ -93,7 +91,7 @@ public class JmsConsumerPriorityDispatchTest extends AmqpTestSupport {
 
         connection.start();
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageProducer producer = session.createProducer(queue);
         MessageConsumer consumer = session.createConsumer(queue);
         Message message = null;
@@ -105,7 +103,7 @@ public class JmsConsumerPriorityDispatchTest extends AmqpTestSupport {
         }
 
         // We need to make sure that all messages are in the prefetch buffer.
-        assertTrue(received.await(10, TimeUnit.SECONDS), "Failed to receive all messages");
+        assertTrue("Failed to receive all messages", received.await(10, TimeUnit.SECONDS));
 
         for (int i = MSG_COUNT - 1; i >= 0; i--) {
             message = consumer.receive(5000);
@@ -114,8 +112,7 @@ public class JmsConsumerPriorityDispatchTest extends AmqpTestSupport {
         }
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testPrefetchedMessageAreNotPriorityOrdered() throws Exception {
         // We are assuming that Broker side priority support is not enabled in the create broker
         // method in AmqpTestSupport.  If that changes then this test will sometimes fail.
@@ -160,12 +157,12 @@ public class JmsConsumerPriorityDispatchTest extends AmqpTestSupport {
             }
         });
 
-        assertFalse(jmsConnection.isLocalMessagePriority(),
-                    "Client side priority ordering expected to be disabled for this test");
+        assertFalse("Client side priority ordering expected to be disabled for this test",
+                    jmsConnection.isLocalMessagePriority());
 
         connection.start();
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageProducer producer = session.createProducer(queue);
         MessageConsumer consumer = session.createConsumer(queue);
         Message message = null;
@@ -177,7 +174,7 @@ public class JmsConsumerPriorityDispatchTest extends AmqpTestSupport {
         }
 
         // We need to make sure that all messages are in the prefetch buffer.
-        assertTrue(received.await(10, TimeUnit.SECONDS), "Failed to receive all messages");
+        assertTrue("Failed to receive all messages", received.await(10, TimeUnit.SECONDS));
 
         for (int i = 0; i < 10; i++) {
             message = consumer.receive(5000);
