@@ -16,32 +16,29 @@
  */
 package org.apache.qpid.jms.discovery;
 
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 
 import java.io.File;
 import java.io.FileOutputStream;
 import java.net.URI;
-import java.nio.file.Files;
-import java.nio.file.Path;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.Connection;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageProducer;
-import javax.jms.Session;
+import jakarta.jms.Connection;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Session;
 
 import org.apache.qpid.jms.JmsConnection;
 import org.apache.qpid.jms.JmsConnectionFactory;
 import org.apache.qpid.jms.JmsConnectionListener;
 import org.apache.qpid.jms.message.JmsInboundMessageDispatch;
 import org.apache.qpid.jms.support.AmqpTestSupport;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInfo;
-import org.junit.jupiter.api.Timeout;
-import org.junit.jupiter.api.io.TempDir;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -53,8 +50,8 @@ public class FileWatcherDiscoveryTest extends AmqpTestSupport {
 
     private static final Logger LOG = LoggerFactory.getLogger(FileWatcherDiscoveryTest.class);
 
-    @TempDir
-    public Path folder;
+    @Rule
+    public TemporaryFolder folder = new TemporaryFolder(new File("./target"));
 
     private CountDownLatch connected;
     private CountDownLatch interrupted;
@@ -65,56 +62,53 @@ public class FileWatcherDiscoveryTest extends AmqpTestSupport {
     private File secondaryBrokerList;
 
     @Override
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        super.setUp(testInfo);
+    @Before
+    public void setUp() throws Exception {
+        super.setUp();
 
         connected = new CountDownLatch(1);
         interrupted = new CountDownLatch(1);
         restored = new CountDownLatch(1);
 
-        primaryBrokerList = Files.createFile(folder.resolve("primaryBrokerURIsFile.txt")).toFile();
-        secondaryBrokerList =  Files.createFile(folder.resolve("secondaryBrokerURIsFile.txt")).toFile();
+        primaryBrokerList = folder.newFile("primaryBrokerURIsFile.txt");
+        secondaryBrokerList = folder.newFile("secondaryBrokerURIsFile.txt");
 
         LOG.info("Broker URIs going to file: {}", primaryBrokerList);
 
         writeOutBrokerURIsToFile(primaryBrokerList);
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testConnectedToStoredBrokerURI() throws Exception {
         assertTrue(primaryBrokerList.exists());
 
         connection = createConnection();
         connection.start();
 
-        assertTrue(connected.await(30, TimeUnit.SECONDS), "connection never connected.");
+        assertTrue("connection never connected.", connected.await(30, TimeUnit.SECONDS));
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testReconnectWhenURIUpdates() throws Exception {
         assertTrue(primaryBrokerList.exists());
 
         connection = createConnection();
         connection.start();
 
-        assertTrue(connected.await(30, TimeUnit.SECONDS), "connection never connected.");
+        assertTrue("connection never connected.", connected.await(30, TimeUnit.SECONDS));
 
         stopPrimaryBroker();
 
-        assertTrue(interrupted.await(30, TimeUnit.SECONDS), "connection should be interrupted.");
+        assertTrue("connection should be interrupted.", interrupted.await(30, TimeUnit.SECONDS));
 
         startPrimaryBroker();
 
         writeOutBrokerURIsToFile(primaryBrokerList);
 
-        assertTrue(restored.await(30, TimeUnit.SECONDS), "connection should have been reestablished.");
+        assertTrue("connection should have been reestablished.", restored.await(30, TimeUnit.SECONDS));
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testReconnectUsingTwoFiles() throws Exception {
         assertTrue(primaryBrokerList.exists());
         assertTrue(secondaryBrokerList.exists());
@@ -122,46 +116,45 @@ public class FileWatcherDiscoveryTest extends AmqpTestSupport {
         connection = createConnection(new File[]{ primaryBrokerList, secondaryBrokerList });
         connection.start();
 
-        assertTrue(connected.await(30, TimeUnit.SECONDS), "connection never connected.");
+        assertTrue("connection never connected.", connected.await(30, TimeUnit.SECONDS));
 
         stopPrimaryBroker();
 
-        assertTrue(interrupted.await(30, TimeUnit.SECONDS), "connection should be interrupted.");
+        assertTrue("connection should be interrupted.", interrupted.await(30, TimeUnit.SECONDS));
 
         startPrimaryBroker();
 
         writeOutBrokerURIsToFile(secondaryBrokerList);
 
-        assertTrue(restored.await(30, TimeUnit.SECONDS), "connection should have been reestablished.");
+        assertTrue("connection should have been reestablished.", restored.await(30, TimeUnit.SECONDS));
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testWithInitiallyNonExistingFile() throws Exception {
         assertTrue(primaryBrokerList.exists());
 
         final String FILENAME = "nonExistentFile.txt";
 
-        File nonExistentFile = new File(folder.toFile(), FILENAME);
+        File nonExistentFile = new File(folder.getRoot(), FILENAME);
         assertFalse(nonExistentFile.exists());
 
         connection = createConnection(new File[]{ primaryBrokerList, nonExistentFile });
         connection.start();
 
-        assertTrue(connected.await(30, TimeUnit.SECONDS), "connection never connected.");
+        assertTrue("connection never connected.", connected.await(30, TimeUnit.SECONDS));
 
         stopPrimaryBroker();
 
-        assertTrue(interrupted.await(30, TimeUnit.SECONDS), "connection should be interrupted.");
+        assertTrue("connection should be interrupted.", interrupted.await(30, TimeUnit.SECONDS));
 
         startPrimaryBroker();
 
-        Files.createFile(folder.resolve(FILENAME));
+        folder.newFile(FILENAME);
         assertTrue(nonExistentFile.exists());
 
         writeOutBrokerURIsToFile(nonExistentFile);
 
-        assertTrue(restored.await(30, TimeUnit.SECONDS), "connection should have been reestablished.");
+        assertTrue("connection should have been reestablished.", restored.await(30, TimeUnit.SECONDS));
     }
 
     protected Connection createConnection() throws Exception {
