@@ -16,35 +16,33 @@
  */
 package org.apache.qpid.jms.failover;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertThrows;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.net.URI;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.Connection;
-import javax.jms.DeliveryMode;
-import javax.jms.ExceptionListener;
-import javax.jms.JMSException;
-import javax.jms.JMSSecurityException;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageProducer;
-import javax.jms.Queue;
-import javax.jms.Session;
-import javax.jms.Topic;
+import jakarta.jms.Connection;
+import jakarta.jms.DeliveryMode;
+import jakarta.jms.ExceptionListener;
+import jakarta.jms.JMSException;
+import jakarta.jms.JMSSecurityException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
+import jakarta.jms.Topic;
 
 import org.apache.activemq.broker.jmx.QueueViewMBean;
 import org.apache.qpid.jms.JmsConnectionFactory;
 import org.apache.qpid.jms.support.AmqpTestSupport;
 import org.apache.qpid.jms.support.Wait;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 
 /**
  * Basic tests for the FailoverProvider implementation
@@ -56,8 +54,7 @@ public class JmsFailoverTest extends AmqpTestSupport {
         return true;
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testFailoverConnects() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI());
         Connection connection = createAmqpConnection(brokerURI);
@@ -65,8 +62,7 @@ public class JmsFailoverTest extends AmqpTestSupport {
         connection.close();
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testFailoverConnectsWithMultipleURIs() throws Exception {
         URI brokerURI = new URI("failover://(amqp://127.0.0.1:5678,amqp://localhost:5777," +
                                 getBrokerAmqpConnectionURI() + ")?failover.useReconnectBackOff=false");
@@ -75,26 +71,22 @@ public class JmsFailoverTest extends AmqpTestSupport {
         connection.close();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected = JMSSecurityException.class)
     public void testCreateConnectionAsUnknwonUser() throws Exception {
-        assertThrows(JMSSecurityException.class, () -> {
-            URI brokerURI = new URI(getAmqpFailoverURI() +
-                "?failover.maxReconnectAttempts=5");
+        URI brokerURI = new URI(getAmqpFailoverURI() +
+            "?failover.maxReconnectAttempts=5");
 
-            JmsConnectionFactory factory = new JmsConnectionFactory(brokerURI);
-            factory.setUsername("unknown");
-            factory.setPassword("unknown");
+        JmsConnectionFactory factory = new JmsConnectionFactory(brokerURI);
+        factory.setUsername("unknown");
+        factory.setPassword("unknown");
 
-            connection = factory.createConnection();
-            assertNotNull(connection);
-            connection.start();
-            connection.close();
-        });
+        connection = factory.createConnection();
+        assertNotNull(connection);
+        connection.start();
+        connection.close();
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testStartupReconnectAttempts() throws Exception {
         URI brokerURI = new URI("failover://(amqp://localhost:5677)" +
                                 "?failover.startupMaxReconnectAttempts=5" +
@@ -112,8 +104,7 @@ public class JmsFailoverTest extends AmqpTestSupport {
         }
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testStartupReconnectAttemptsMultipleHosts() throws Exception {
         URI brokerURI = new URI("failover://(amqp://localhost:5678,amqp://localhost:5677)" +
                                 "?failover.startupMaxReconnectAttempts=6" +
@@ -131,8 +122,7 @@ public class JmsFailoverTest extends AmqpTestSupport {
         }
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testStartFailureWithAsyncExceptionListener() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI() +
             "?failover.maxReconnectAttempts=5" +
@@ -153,11 +143,10 @@ public class JmsFailoverTest extends AmqpTestSupport {
 
         stopPrimaryBroker();
 
-        assertTrue(failed.await(15, TimeUnit.SECONDS), "No async exception");
+        assertTrue("No async exception", failed.await(15, TimeUnit.SECONDS));
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testBasicStateRestoration() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI());
 
@@ -165,7 +154,7 @@ public class JmsFailoverTest extends AmqpTestSupport {
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         session.createProducer(queue);
         session.createConsumer(queue);
 
@@ -174,76 +163,74 @@ public class JmsFailoverTest extends AmqpTestSupport {
 
         restartPrimaryBroker();
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have a new connection.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getCurrentConnectionsCount() == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)), "Should have a new connection.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should one new Queue Subscription.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getQueueSubscribers().length == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)), "Should one new Queue Subscription.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should one new Queue Producer.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getQueueProducers().length == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)), "Should one new Queue Producer.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)));
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testDurableSubscriberRestores() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI());
 
         connection = createAmqpConnection(brokerURI);
-        connection.setClientID(testMethodName);
+        connection.setClientID(name.getMethodName());
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Topic topic = session.createTopic(testMethodName);
-        MessageConsumer consumer = session.createDurableSubscriber(topic, testMethodName);
+        Topic topic = session.createTopic(name.getMethodName());
+        MessageConsumer consumer = session.createDurableSubscriber(topic, name.getMethodName());
         assertNotNull(consumer);
 
         assertEquals(1, brokerService.getAdminView().getDurableTopicSubscribers().length);
 
         restartPrimaryBroker();
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have a new connection.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getCurrentConnectionsCount() == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)), "Should have a new connection.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have no inactive subscribers.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getInactiveDurableTopicSubscribers().length == 0;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)), "Should have no inactive subscribers.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have one durable sub.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getDurableTopicSubscribers().length == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)), "Should have one durable sub.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)));
     }
 
-    @Test
-    @Timeout(90)
+    @Test(timeout=90000)
     public void testBadFirstURIConnectsAndProducerWorks() throws Exception {
         URI brokerURI = new URI("failover://(amqp://localhost:5679," + getBrokerAmqpConnectionURI() + ")");
 
@@ -252,7 +239,7 @@ public class JmsFailoverTest extends AmqpTestSupport {
 
         final int MSG_COUNT = 10;
         final Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         final MessageProducer producer = session.createProducer(queue);
         producer.setDeliveryMode(DeliveryMode.PERSISTENT);
         final CountDownLatch failed = new CountDownLatch(1);
@@ -263,21 +250,20 @@ public class JmsFailoverTest extends AmqpTestSupport {
             producer.send(session.createTextMessage("Message: " + i));
         }
 
-        final QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        final QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have all messages sent.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == MSG_COUNT;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)), "Should have all messages sent.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)));
 
         assertFalse(failed.getCount() == 0);
     }
 
-    @Test
-    @Timeout(90)
+    @Test(timeout=90000)
     public void testNonTxProducerRecoversAfterFailover() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI());
 
@@ -286,7 +272,7 @@ public class JmsFailoverTest extends AmqpTestSupport {
 
         final int MSG_COUNT = 20;
         final Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         final MessageProducer producer = session.createProducer(queue);
         producer.setDeliveryMode(DeliveryMode.PERSISTENT);
         final CountDownLatch failed = new CountDownLatch(1);
@@ -320,38 +306,37 @@ public class JmsFailoverTest extends AmqpTestSupport {
         TimeUnit.SECONDS.sleep(2);  // Gives FailoverProvider some CPU time
         restartPrimaryBroker();
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have a new connection.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getCurrentConnectionsCount() == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)), "Should have a new connection.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have a recovered producer.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getQueueProducers().length == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)), "Should have a recovered producer.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)));
 
-        final QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        final QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have all messages sent.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == MSG_COUNT;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)), "Should have all messages sent.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)));
 
         assertFalse(failed.getCount() == 0);
         connection.close();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testPullConsumerTimedReceiveRecovers() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI() + "?jms.prefetchPolicy.all=0");
 
@@ -362,7 +347,7 @@ public class JmsFailoverTest extends AmqpTestSupport {
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         final MessageConsumer consumer = session.createConsumer(queue);
 
         Thread receiver = new Thread(new Runnable() {
@@ -389,30 +374,29 @@ public class JmsFailoverTest extends AmqpTestSupport {
 
         restartPrimaryBroker();
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have a new connection.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getCurrentConnectionsCount() == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)), "Should have a new connection.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should one new Queue Subscription.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getQueueSubscribers().length == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)), "Should one new Queue Subscription.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)));
 
         MessageProducer producer = session.createProducer(queue);
         producer.send(session.createMessage());
 
-        assertTrue(received.await(30, TimeUnit.SECONDS), "Consumer should have recovered");
+        assertTrue("Consumer should have recovered", received.await(30, TimeUnit.SECONDS));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testPullConsumerReceiveRecovers() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI() + "?jms.prefetchPolicy.all=0");
 
@@ -423,7 +407,7 @@ public class JmsFailoverTest extends AmqpTestSupport {
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         final MessageConsumer consumer = session.createConsumer(queue);
 
         Thread receiver = new Thread(new Runnable() {
@@ -450,25 +434,25 @@ public class JmsFailoverTest extends AmqpTestSupport {
 
         restartPrimaryBroker();
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have a new connection.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getCurrentConnectionsCount() == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)), "Should have a new connection.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should one new Queue Subscription.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getQueueSubscribers().length == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)), "Should one new Queue Subscription.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)));
 
         MessageProducer producer = session.createProducer(queue);
         producer.send(session.createMessage());
 
-        assertTrue(received.await(30, TimeUnit.SECONDS), "Consumer should have recovered");
+        assertTrue("Consumer should have recovered", received.await(30, TimeUnit.SECONDS));
     }
 }
