@@ -16,26 +16,25 @@
  */
 package org.apache.qpid.jms.failover;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.net.URI;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.JMSException;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.Queue;
-import javax.jms.Session;
-import javax.jms.TransactionRolledBackException;
+import jakarta.jms.JMSException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
+import jakarta.jms.TransactionRolledBackException;
 
 import org.apache.activemq.broker.jmx.QueueViewMBean;
 import org.apache.qpid.jms.support.AmqpTestSupport;
 import org.apache.qpid.jms.support.Wait;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 
 /**
  * Test MessageConsumer behavior when in a TX and failover occurs.
@@ -51,8 +50,7 @@ public class JmsTxConsumerFailoverTest extends AmqpTestSupport {
      * Test that the TX doesn't start until the first ack so a failover
      * before that should allow Commit to work as expected.
      */
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testTxConsumerReceiveAfterFailoverCommits() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI());
 
@@ -61,35 +59,35 @@ public class JmsTxConsumerFailoverTest extends AmqpTestSupport {
 
         final int MSG_COUNT = 5;
         final Session session = connection.createSession(true, Session.SESSION_TRANSACTED);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         final MessageConsumer consumer = session.createConsumer(queue);
 
         sendMessages(connection, queue, MSG_COUNT);
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(MSG_COUNT, proxy.getQueueSize());
 
         stopPrimaryBroker();
         restartPrimaryBroker();
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have a new connection.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getCurrentConnectionsCount() == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)), "Should have a new connection.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(100)));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have a recovered consumer.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return brokerService.getAdminView().getQueueSubscribers().length == 1;
             }
-        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)), "Should have a recovered consumer.");
+        }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(50)));
 
         for (int i = 0; i < MSG_COUNT; ++i) {
             Message received = consumer.receive(3000);
-            assertNotNull(received, "Mesage was not expected but not received");
+            assertNotNull("Mesage was not expected but not received", received);
         }
 
         try {
@@ -102,8 +100,7 @@ public class JmsTxConsumerFailoverTest extends AmqpTestSupport {
         assertEquals(0, proxy.getQueueSize());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testTxConsumerReceiveThenFailoverCommitFails() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI());
 
@@ -112,22 +109,22 @@ public class JmsTxConsumerFailoverTest extends AmqpTestSupport {
 
         final int MSG_COUNT = 5;
         final Session session = connection.createSession(true, Session.SESSION_TRANSACTED);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         final MessageConsumer consumer = session.createConsumer(queue);
 
         sendMessages(connection, queue, MSG_COUNT);
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(MSG_COUNT, proxy.getQueueSize());
 
         for (int i = 0; i < MSG_COUNT; ++i) {
             Message received = consumer.receive(3000);
-            assertNotNull(received, "Mesage was not expected but not received");
+            assertNotNull("Mesage was not expected but not received", received);
         }
 
         stopPrimaryBroker();
         restartPrimaryBroker();
 
-        proxy = getProxyToQueue(testMethodName);
+        proxy = getProxyToQueue(name.getMethodName());
         assertEquals(MSG_COUNT, proxy.getQueueSize());
 
         try {
@@ -141,8 +138,7 @@ public class JmsTxConsumerFailoverTest extends AmqpTestSupport {
         assertEquals(MSG_COUNT, proxy.getQueueSize());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testTxConsumerRollbackAfterFailoverGetsNoErrors() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI());
 
@@ -151,25 +147,25 @@ public class JmsTxConsumerFailoverTest extends AmqpTestSupport {
 
         final int MSG_COUNT = 5;
         final Session session = connection.createSession(true, Session.SESSION_TRANSACTED);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         final MessageConsumer consumer = session.createConsumer(queue);
 
         sendMessages(connection, queue, MSG_COUNT);
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(MSG_COUNT, proxy.getQueueSize());
 
         for (int i = 0; i < MSG_COUNT; ++i) {
             Message received = consumer.receive(3000);
-            assertNotNull(received, "Mesage was not expected but not received");
+            assertNotNull("Mesage was not expected but not received", received);
         }
 
-        proxy = getProxyToQueue(testMethodName);
+        proxy = getProxyToQueue(name.getMethodName());
         assertEquals(MSG_COUNT, proxy.getQueueSize());
 
         stopPrimaryBroker();
         restartPrimaryBroker();
 
-        proxy = getProxyToQueue(testMethodName);
+        proxy = getProxyToQueue(name.getMethodName());
         assertEquals(MSG_COUNT, proxy.getQueueSize());
 
         try {
@@ -188,8 +184,7 @@ public class JmsTxConsumerFailoverTest extends AmqpTestSupport {
      * Tests that if some receives happen and then a failover followed by additional
      * receives the commit will fail and no messages are left on the broker.
      */
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testTxConsumerReceiveWorksAfterFailoverButCommitFails() throws Exception {
         URI brokerURI = new URI(getAmqpFailoverURI());
 
@@ -198,16 +193,16 @@ public class JmsTxConsumerFailoverTest extends AmqpTestSupport {
 
         final int MSG_COUNT = 10;
         final Session session = connection.createSession(true, Session.SESSION_TRANSACTED);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         final MessageConsumer consumer = session.createConsumer(queue);
 
         sendMessages(connection, queue, MSG_COUNT);
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(MSG_COUNT, proxy.getQueueSize());
 
         for (int i = 0; i < MSG_COUNT / 2; ++i) {
             Message received = consumer.receive(3000);
-            assertNotNull(received, "Mesage was not expected but not received");
+            assertNotNull("Mesage was not expected but not received", received);
             LOG.info("consumer received message #{} - {}", i + 1, received.getJMSMessageID());
         }
 
@@ -216,12 +211,12 @@ public class JmsTxConsumerFailoverTest extends AmqpTestSupport {
         stopPrimaryBroker();
         restartPrimaryBroker();
 
-        proxy = getProxyToQueue(testMethodName);
+        proxy = getProxyToQueue(name.getMethodName());
         assertEquals(MSG_COUNT, proxy.getQueueSize());
 
         for (int i = 0; i < MSG_COUNT / 2; ++i) {
             Message received = consumer.receive(3000);
-            assertNotNull(received, "Mesage was not expected but not received");
+            assertNotNull("Mesage was not expected but not received", received);
             LOG.info("consumer received message #{} - {}", i + 1, received.getJMSMessageID());
         }
 
