@@ -16,40 +16,37 @@
  */
 package org.apache.qpid.jms.producer;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.util.Arrays;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.BytesMessage;
-import javax.jms.Connection;
-import javax.jms.DeliveryMode;
-import javax.jms.JMSSecurityException;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageProducer;
-import javax.jms.Queue;
-import javax.jms.Session;
-import javax.jms.TextMessage;
+import jakarta.jms.BytesMessage;
+import jakarta.jms.DeliveryMode;
+import jakarta.jms.JMSSecurityException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
+import jakarta.jms.TextMessage;
 
 import org.apache.activemq.broker.jmx.QueueViewMBean;
 import org.apache.qpid.jms.provider.amqp.message.AmqpMessageSupport;
 import org.apache.qpid.jms.support.AmqpTestSupport;
 import org.apache.qpid.jms.support.Wait;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 
 /**
  * Test Various behaviors of the JMS MessageProducer implementation.
  */
 public class JmsMessageProducerTest extends AmqpTestSupport {
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testCreateMessageProducer() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
@@ -57,15 +54,14 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         session.createProducer(queue);
 
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(0, proxy.getQueueSize());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testProducerNotAuthorized() throws Exception {
         connection = createAmqpConnection("guest", "password");
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -78,20 +74,19 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSendMultipleMessagesPersistent() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageProducer producer = session.createProducer(queue);
 
         final int MSG_COUNT = 100;
 
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(0, proxy.getQueueSize());
 
         producer.setDeliveryMode(DeliveryMode.PERSISTENT);
@@ -112,20 +107,19 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
         assertEquals(MSG_COUNT, proxy.getQueueSize());
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSendMultipleMessagesNonPersistent() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageProducer producer = session.createProducer(queue);
 
         final int MSG_COUNT = 100;
 
-        final QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        final QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(0, proxy.getQueueSize());
 
         producer.setDeliveryMode(DeliveryMode.NON_PERSISTENT);
@@ -141,19 +135,18 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
             LOG.trace("sent message: {}", i);
         }
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should all make it to the Queue.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == MSG_COUNT;
             }
-        }), "Should all make it to the Queue.");
+        }));
 
         producer.close();
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testPersistentSendsAreMarkedPersistent() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
@@ -161,11 +154,11 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageProducer producer = session.createProducer(queue);
         producer.setDeliveryMode(DeliveryMode.PERSISTENT);
 
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(0, proxy.getQueueSize());
 
         Message message = session.createMessage();
@@ -179,46 +172,7 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
         assertTrue(message.getJMSDeliveryMode() == DeliveryMode.PERSISTENT);
     }
 
-    @Test
-    @Timeout(20)
-    public void testSendForeignMessage() throws Exception {
-        connection = createAmqpConnection();
-        assertNotNull(connection);
-        connection.start();
-
-        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
-        MessageProducer producer = session.createProducer(queue);
-
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
-        assertEquals(0, proxy.getQueueSize());
-
-        String foreignPropKey = "myForeignMessageProp";
-        String foreignPropValue = "ABC456XYZ";
-
-        Connection activeMQConnection = createActiveMQConnection();
-        try {
-            Session activeMQSession = activeMQConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-
-            Message foreignMessage = activeMQSession.createMessage();
-            foreignMessage.setStringProperty(foreignPropKey, foreignPropValue);
-
-            producer.send(foreignMessage);
-        } finally {
-            activeMQConnection.close();
-        }
-
-        assertEquals(1, proxy.getQueueSize());
-
-        MessageConsumer consumer = session.createConsumer(queue);
-        Message receivedMessage = consumer.receive(5000);
-        assertNotNull(receivedMessage, "Did not receive message as expected");
-        assertEquals(foreignPropValue, receivedMessage.getStringProperty(foreignPropKey), "Unexpected property value");
-    }
-
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testProducerWithNoTTLSendsMessagesWithoutTTL() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
@@ -226,10 +180,10 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageProducer producer = session.createProducer(queue);
 
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(0, proxy.getQueueSize());
 
         Message message = session.createMessage();
@@ -243,8 +197,7 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
         assertEquals(0, message.getJMSExpiration());
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testProducerWithNoMessageIdCanBeConsumed() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
@@ -252,11 +205,11 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageProducer producer = session.createProducer(queue);
         producer.setDisableMessageID(true);
 
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(0, proxy.getQueueSize());
 
         for (int i = 0; i < 10; ++i) {
@@ -285,14 +238,13 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
         return builder.toString();
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testSendLargeMessage() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
         connection.start();
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        String queueName = testMethodName.toString();
+        String queueName = name.toString();
         Queue queue = session.createQueue(queueName);
 
         MessageProducer producer = session.createProducer(queue);
@@ -313,20 +265,17 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
         assertEquals(messageText, textMessage.getText());
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testProducerWithTTL() throws Exception {
         doProducerWithTTLTestImpl(false, null);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testProducerWithTTLDisableTimestamp() throws Exception {
         doProducerWithTTLTestImpl(true, null);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testProducerWithTTLDisableTimestampAndNoAmqpTtl() throws Exception {
         doProducerWithTTLTestImpl(true, 0L);
     }
@@ -338,7 +287,7 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
 
         Message message = session.createMessage();
         if(propJMS_AMQP_TTL != null) {
@@ -361,6 +310,6 @@ public class JmsMessageProducerTest extends AmqpTestSupport {
                     new Object[] { message.getJMSExpiration(), message.getJMSTimestamp(),
                     message.getJMSExpiration() - message.getJMSTimestamp()});
         }
-        assertNull(message, "Unexpected message received, see log for details");
+        assertNull("Unexpected message received, see log for details", message);
     }
 }
