@@ -16,19 +16,19 @@
  */
 package org.apache.qpid.jms.producer;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
 
-import javax.jms.Queue;
-import javax.jms.QueueConnection;
-import javax.jms.QueueSender;
-import javax.jms.QueueSession;
-import javax.jms.Session;
+import jakarta.jms.Queue;
+import jakarta.jms.QueueConnection;
+import jakarta.jms.QueueSender;
+import jakarta.jms.QueueSession;
+import jakarta.jms.Session;
 
 import org.apache.activemq.broker.jmx.QueueViewMBean;
 import org.apache.qpid.jms.JmsConnectionFactory;
 import org.apache.qpid.jms.support.AmqpTestSupport;
-import org.junit.jupiter.api.Test;
+import org.junit.Test;
 
 /**
  * Test basic QueueSender functionality.
@@ -43,11 +43,11 @@ public class JmsQueueSenderTest extends AmqpTestSupport {
 
         QueueSession session = connection.createQueueSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         QueueSender sender = session.createSender(queue);
         assertNotNull(sender);
 
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(0, proxy.getQueueSize());
         connection.close();
     }
